# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/review_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/review_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%fsai_grpc_api/protos/review_api.proto\":\n$GetNextReviewImageByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"9\n%GetNextReviewImageByMissionIdResponse\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x32{\n\tReviewApi\x12n\n\x1dGetNextReviewImageByMissionId\x12%.GetNextReviewImageByMissionIdRequest\x1a&.GetNextReviewImageByMissionIdResponseb\x06proto3'
)




_GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST = _descriptor.Descriptor(
  name='GetNextReviewImageByMissionIdRequest',
  full_name='GetNextReviewImageByMissionIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='GetNextReviewImageByMissionIdRequest.mission_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=99,
)


_GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE = _descriptor.Descriptor(
  name='GetNextReviewImageByMissionIdResponse',
  full_name='GetNextReviewImageByMissionIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='GetNextReviewImageByMissionIdResponse.image_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=158,
)

DESCRIPTOR.message_types_by_name['GetNextReviewImageByMissionIdRequest'] = _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST
DESCRIPTOR.message_types_by_name['GetNextReviewImageByMissionIdResponse'] = _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNextReviewImageByMissionIdRequest = _reflection.GeneratedProtocolMessageType('GetNextReviewImageByMissionIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageByMissionIdRequest)
  })
_sym_db.RegisterMessage(GetNextReviewImageByMissionIdRequest)

GetNextReviewImageByMissionIdResponse = _reflection.GeneratedProtocolMessageType('GetNextReviewImageByMissionIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.review_api_pb2'
  # @@protoc_insertion_point(class_scope:GetNextReviewImageByMissionIdResponse)
  })
_sym_db.RegisterMessage(GetNextReviewImageByMissionIdResponse)



_REVIEWAPI = _descriptor.ServiceDescriptor(
  name='ReviewApi',
  full_name='ReviewApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=160,
  serialized_end=283,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNextReviewImageByMissionId',
    full_name='ReviewApi.GetNextReviewImageByMissionId',
    index=0,
    containing_service=None,
    input_type=_GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST,
    output_type=_GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REVIEWAPI)

DESCRIPTOR.services_by_name['ReviewApi'] = _REVIEWAPI

# @@protoc_insertion_point(module_scope)
