# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import area_of_interest_api_pb2 as fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2


class AreaOfInterestApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateAreaOfInterest = channel.unary_unary(
                '/AreaOfInterestApi/FindOrCreateAreaOfInterest',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
                )
        self.FindAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/FindAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.FromString,
                )
        self.ListAreaOfInterests = channel.unary_unary(
                '/AreaOfInterestApi/ListAreaOfInterests',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.FromString,
                )
        self.UpdateAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/UpdateAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.FromString,
                )
        self.DeleteAreaOfInterestById = channel.unary_unary(
                '/AreaOfInterestApi/DeleteAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
                )
        self.GetAreaOfInterestOverlapPercent = channel.unary_unary(
                '/AreaOfInterestApi/GetAreaOfInterestOverlapPercent',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.FromString,
                )
        self.GetAoiKmlDataByMissionId = channel.unary_unary(
                '/AreaOfInterestApi/GetAoiKmlDataByMissionId',
                request_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.FromString,
                )


class AreaOfInterestApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateAreaOfInterest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FindAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAreaOfInterests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAreaOfInterestOverlapPercent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAoiKmlDataByMissionId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AreaOfInterestApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateAreaOfInterest': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateAreaOfInterest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.SerializeToString,
            ),
            'FindAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.FindAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.SerializeToString,
            ),
            'ListAreaOfInterests': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAreaOfInterests,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.SerializeToString,
            ),
            'UpdateAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.SerializeToString,
            ),
            'DeleteAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.SerializeToString,
            ),
            'GetAreaOfInterestOverlapPercent': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAreaOfInterestOverlapPercent,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.SerializeToString,
            ),
            'GetAoiKmlDataByMissionId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAoiKmlDataByMissionId,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AreaOfInterestApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AreaOfInterestApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateAreaOfInterest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/FindOrCreateAreaOfInterest',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FindAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/FindAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.FindAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAreaOfInterests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/ListAreaOfInterests',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.ListAreaOfInterestsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/UpdateAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.UpdateAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/DeleteAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAreaOfInterestOverlapPercent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/GetAreaOfInterestOverlapPercent',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAreaOfInterestOverlapPercentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAoiKmlDataByMissionId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreaOfInterestApi/GetAoiKmlDataByMissionId',
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_area__of__interest__api__pb2.GetAoiKmlDataByMissionIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
