# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/category_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/category_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'fsai_grpc_api/protos/category_api.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xfd\x01\n\x08\x43\x61tegory\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x65num\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12)\n\x08includes\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08\x65xcludes\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\".\n\x0f\x43\x61tegoryRequest\x12\x1b\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32\t.Category\"Q\n\x10\x43\x61tegoryResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1b\n\x08\x63\x61tegory\x18\x02 \x01(\x0b\x32\t.Category\"Y\n\x16ListCategoriesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\ncategories\x18\x02 \x03(\x0b\x32\t.Category2\x8d\x01\n\x0b\x43\x61tegoryApi\x12;\n\x14\x46indOrCreateCategory\x12\x10.CategoryRequest\x1a\x11.CategoryResponse\x12\x41\n\x0eListCategories\x12\x16.google.protobuf.Empty\x1a\x17.ListCategoriesResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_CATEGORY = _descriptor.Descriptor(
  name='Category',
  full_name='Category',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Category.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Category.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enum', full_name='Category.enum', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='Category.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includes', full_name='Category.includes', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excludes', full_name='Category.excludes', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Category.created_at', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='Category.updated_at', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=423,
)


_CATEGORYREQUEST = _descriptor.Descriptor(
  name='CategoryRequest',
  full_name='CategoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='CategoryRequest.category', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=471,
)


_CATEGORYRESPONSE = _descriptor.Descriptor(
  name='CategoryResponse',
  full_name='CategoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='CategoryResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='CategoryResponse.category', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=554,
)


_LISTCATEGORIESRESPONSE = _descriptor.Descriptor(
  name='ListCategoriesResponse',
  full_name='ListCategoriesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListCategoriesResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='categories', full_name='ListCategoriesResponse.categories', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=645,
)

_CATEGORY.fields_by_name['includes'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CATEGORY.fields_by_name['excludes'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_CATEGORY.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CATEGORY.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CATEGORYREQUEST.fields_by_name['category'].message_type = _CATEGORY
_CATEGORYRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_CATEGORYRESPONSE.fields_by_name['category'].message_type = _CATEGORY
_LISTCATEGORIESRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTCATEGORIESRESPONSE.fields_by_name['categories'].message_type = _CATEGORY
DESCRIPTOR.message_types_by_name['Category'] = _CATEGORY
DESCRIPTOR.message_types_by_name['CategoryRequest'] = _CATEGORYREQUEST
DESCRIPTOR.message_types_by_name['CategoryResponse'] = _CATEGORYRESPONSE
DESCRIPTOR.message_types_by_name['ListCategoriesResponse'] = _LISTCATEGORIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Category = _reflection.GeneratedProtocolMessageType('Category', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORY,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:Category)
  })
_sym_db.RegisterMessage(Category)

CategoryRequest = _reflection.GeneratedProtocolMessageType('CategoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORYREQUEST,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:CategoryRequest)
  })
_sym_db.RegisterMessage(CategoryRequest)

CategoryResponse = _reflection.GeneratedProtocolMessageType('CategoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _CATEGORYRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:CategoryResponse)
  })
_sym_db.RegisterMessage(CategoryResponse)

ListCategoriesResponse = _reflection.GeneratedProtocolMessageType('ListCategoriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCATEGORIESRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.category_api_pb2'
  # @@protoc_insertion_point(class_scope:ListCategoriesResponse)
  })
_sym_db.RegisterMessage(ListCategoriesResponse)



_CATEGORYAPI = _descriptor.ServiceDescriptor(
  name='CategoryApi',
  full_name='CategoryApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=648,
  serialized_end=789,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateCategory',
    full_name='CategoryApi.FindOrCreateCategory',
    index=0,
    containing_service=None,
    input_type=_CATEGORYREQUEST,
    output_type=_CATEGORYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCategories',
    full_name='CategoryApi.ListCategories',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTCATEGORIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CATEGORYAPI)

DESCRIPTOR.services_by_name['CategoryApi'] = _CATEGORYAPI

# @@protoc_insertion_point(module_scope)
